rm(list=ls())
library(tidyverse)
library(factoextra)
library(corrplot)
library(rstatix)
library(survival)
library(survminer)
library(car)
library(viridis)
library(olsrr)

setwd("C:/Users/rvanhespen/Dropbox/PhD_Research/20 Trait-based WoO/DATA rev01/")

####### --- plotting settings -----
speciesnames <- c("AM" = "A. marina","LR" = "L. racemosa","SA" = "S. apetala",
                  "AC" = "A. corniculatum","RS" = "R. stylosa","KO" = "K. obovata",
                  "BS" = "B. sexangula",  "BG" = "B. gymnorrhiza")
treatcols <- c("-6" = "#D01C8B", "0" = "#000000", "3" = "#B8E186") 
statecols <- c("-1" = "#D3D3D3", "0" = "#A00101", "1" = "#CA921B", "2" = "#81D250")

#### --- LOAD DATA ------
# dataset of survival over time
survival <- data.frame(read.csv("survival.csv")) 

count_srv <- survival %>%
  group_by(day, species, treatment, state) %>%
  summarise(n = n()) %>%
  ungroup() %>%
  complete(day, treatment, state, fill = list(n = 0))

# dataset with measurements at end of the experiment (day 34)
finalstate <- survival %>%
  filter(day == 34) %>%
  select(-day)

mean_watertemp_during_experiment <- tibble(
  species = c("AM", "LR", "SA", "AC", "RS", "KO", "BS", "BG"),
  watertemp_C = c(30.7, 30.7, 22.6, 30.7, 30.7, 26.4, 30.7, 30.7))

df <- data.frame(read.csv("finalmeasurements.csv")) %>%
  left_join(finalstate) %>%
  left_join(mean_watertemp_during_experiment) %>%
  mutate(netCEDdislodge_cm = CEDdislodge_cm - treatment,
         netCEDtopple_cm = CEDtopple_cm - treatment, 
         AGR = ((maxshoot_cm - proplength_cm)/34),
         RGR = ((log(maxshoot_cm) - log(proplength_cm))/(34-0)),
         shootgrowth_cm = maxshoot_cm - proplength_cm,
         rootshootratio_cm = maxroot_cm / maxshoot_cm,
         adjrootshootratio_cm = maxroot_cm / shootgrowth_cm,
         rsratio_g = root_g/above_g) %>%
  filter(state %in% c(1,2)) 


df.cor <- df %>%
  select(pioneerrank, vivipary, proplength_cm, propweight_g, treatment, 
         maxshoot_cm, maxroot_cm, nr_roots,  CEDtopple_cm,  CEDdislodge_cm, 
         netCEDtopple_cm, netCEDdislodge_cm) %>%
  drop_na()

# data for supplementary figures
growth        <- data.frame(read.csv("growth.csv")) 
deadseedlings <- data.frame(read.csv("deadseedlings.csv"))
onced         <- data.frame(read.csv("ongoingCEDkandelia.csv")) %>%
  group_by(day, type) %>%
  mutate(meanlength = mean(longestroot_cm),
         meanshoot = mean(shoot_cm))

# arrange species orders
df$species        <- factor(df$species, levels = c("AM", "LR", "SA", "AC", "RS", "KO", "BS", "BG"))
survival$species  <- factor(survival$species, levels = c("AM", "LR", "SA", "AC", "RS", "KO", "BS", "BG"))
growth$species    <- factor(growth$species, levels = c("AM", "LR", "SA", "AC", "RS", "KO", "BS", "BG"))
deadseedlings$species     <- factor(deadseedlings$species, levels = c("AM", "LR", "SA", "AC", "RS", "KO", "BS", "BG"))
deadseedlings$state       <- factor(deadseedlings$state, levels = c("Toppled", "Dead"))

####################################################
####################################################
############## --- Main results ----- ##############
####################################################
####################################################

#### SURVIVAL ####
count_srv %>%
  filter(!is.na(species), !is.na(state), day %in% c(7,10,13,17,20,24,27,31,34)) %>%
  ggplot(aes(x = (day), y = n, fill = factor(state))) +
  geom_bar(stat = "identity", colour = "white", size=0.002) +
  facet_grid(species~treatment) +
  scale_y_continuous(breaks = seq(0, 12, 3), limits = c(0, 12)) +
  scale_x_continuous(breaks = c(7,10,13,17,20,24,27,31,34)) +
  scale_fill_manual(values = statecols, 
                    labels = c("-1" = "Not Germinated",
                               "0" = "Dead", 
                               "1" = "Toppled", 
                               "2" = "Alive"),
                    guide = guide_legend(reverse=TRUE)) +
  labs(x = "Day", y = "Count", fill = "State") +
  theme_bw() +
  theme(legend.position="right") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1)) 

# find specific state counts, e.g. per species or per treatment
survival %>% 
  filter(species == "LR", treatment == -6, day == 34)

#### GROWTH ####
df %>%
  group_by(species, treatment) %>%
  summarise(meanroot = mean(maxroot_cm * -1, na.rm = TRUE),
            meanshoot = mean(maxshoot_cm, na.rm = TRUE)) %>%
  pivot_longer(-c(species, treatment), names_to = "plantpart", values_to = "length_cm") %>%
  ggplot(aes(x = treatment, y = length_cm, fill = as.factor(species)))+
  geom_bar(stat = "identity", alpha = 0.6) + 
  geom_point(data = filter(df, !is.na(treatment)), 
             aes(x = treatment, y = maxshoot_cm), alpha = 0.3) +
  geom_point(data = filter(df, !is.na(treatment)), 
             aes(x = treatment, y = maxroot_cm * -1), alpha = 0.3) +
  geom_hline(yintercept = 0) +
  facet_wrap(~species, nrow = 3) +
  theme_bw() +
  labs(x = "Cumulative sediment treatment (cm)", 
       y = "Max. root & shoot length (cm)") +
  theme(legend.position = "bottom") +
  scale_x_continuous(breaks = c(-6,0,3)) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  scale_fill_brewer(palette = "Dark2", labels= speciesnames) 

no_na_rgr %>%
  ggplot(aes(x = treatment, y = RGR)) +
  geom_point() +
  facet_wrap(~species) +
  theme_light()

##### CORRELATIONS ####
testRes <- cor.mtest(df.cor, method = "pearson", conf.level = 0.95)
corrplot(cor(df.cor, method = "pearson"), p.mat = testRes$p,
         insig='blank',
         order = 'original', addCoef.col = 'black', 
         col = COL2('PiYG'), type = "lower", number.cex = 0.8)
         #tl.pos='n')

#### CED PER ROOTLENGTH ####
df %>%
  ggplot(aes(x = maxroot_cm , y = netCEDdislodge_cm, colour =  species)) +
  geom_point(size = 2, alpha =0.7) +
  scale_colour_brewer(palette = "Dark2", labels= speciesnames) +
  geom_smooth(method = "lm", se = FALSE, colour = "black", size = 0.1) +
  labs(x = "Max. rootlength (cm)", y = "Net CED dislodgement (cm)", colour = "Species") +
  theme_bw() +
  theme(legend.position="bottom") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  ylim(0,25)

cor.test(df.cor$maxroot_cm, df.cor$netCEDdislodge_cm, method = "pearson")
summary(lm(netCEDdislodge_cm ~ maxroot_cm , df.cor))

df %>%
  ggplot(aes(x = maxroot_cm, y = netCEDtopple_cm, colour = species)) +
  geom_point(size = 2, alpha =0.7) +
  scale_colour_brewer(palette = "Dark2") +
  geom_smooth(method = "lm", se = FALSE, colour = "black", size = 0.1) +
  labs(x = "Max. rootlength (cm)", y = "Net CED toppling (cm)") +
  theme_bw() +
  theme(legend.position="bottom") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  ylim(0,25)

cor.test(df.cor$maxroot_cm, df.cor$netCEDtopple_cm, method = "pearson")
summary(lm(netCEDtopple_cm ~ maxroot_cm , df.cor))

cor.test(df.cor$netCEDdislodge_cm, df.cor$netCEDtopple_cm, method = "pearson")

#There was no significant correlation between the number of primary roots and CEDtopple nor CEDdislodge

dfx <- df %>%
  filter(!species %in% c("KO", "RS")) 

cor.test(dfx$netCEDdislodge_cm, dfx$nr_roots, method = "pearson")
summary(lm(CEDdislodge_cm ~ nr_roots,df))

#### MORPHOLOGY AND CED AND ROOTS ####
df %>%
  ggplot(aes(x = treatment,  colour= species, y = maxroot_cm)) + 
  geom_jitter(alpha = 0.7, size = 2, height = 0, width = 0.05) +
  facet_wrap(~pioneerrank) +
  theme_bw() +
  theme(legend.position="bottom") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  scale_colour_brewer(palette = "Dark2", labels= speciesnames) +
  geom_smooth(method = "lm", formula = y ~ x, aes(group = species, colour = species), linetype = "dashed", se = FALSE, size = 0.1) +
  geom_smooth(method = "lm", colour = "black", aes(group = pioneerrank), se= FALSE) +
  scale_x_continuous(breaks = c(-6, 0,3))

df %>% group_by(pioneerrank) %>% cor_test(treatment, maxroot_cm)
summary(lm(maxroot_cm ~ treatment, data = (filter(df, pioneerrank == 1))))

df %>%
  ggplot(aes(x = treatment,  colour= species, y = netCEDtopple_cm)) + 
  geom_jitter(alpha = 0.7, size = 2, height= 0, width =0.05) +
  facet_wrap(~pioneerrank) +
  theme_bw() +
  theme(legend.position="bottom") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  scale_colour_brewer(palette = "Dark2", labels= speciesnames) +
  geom_smooth(method = "lm", formula = y ~ x, aes(group = species, colour = species), linetype = "dashed", se = FALSE, size = 0.1) +
  geom_smooth(method = "lm", colour = "black", aes(group = pioneerrank), se= FALSE) +
  scale_x_continuous(breaks = c(-6, 0,3)) +
  labs(colour = "Species")

df %>% group_by(pioneerrank) %>% cor_test(treatment, netCEDtopple_cm)
summary(lm(netCEDtopple_cm ~ treatment, filter(df, pioneerrank == 3)))


#CED ~ maxroot + maxshoot
mod <- lm(netCEDtopple_cm ~ maxroot_cm + maxshoot_cm, df)
summary(mod)
ols_vif_tol(mod)

#### SHOOT LENGTH ####
# shootlength per proplength
df %>%
  filter(maxshoot_cm >0) %>%
  ggplot(aes(x = proplength_cm, y = maxshoot_cm)) +
  geom_point(aes(colour = species, shape = as.factor(treatment)), alpha = 0.7) +
  scale_colour_brewer(palette = "Dark2", labels= speciesnames) +
  geom_smooth(method = "lm", se = FALSE, size = 0.1, colour = "black") +
  theme_light() +
  labs(x = "Propagule length (cm)", y = "Shootlength at day 34 (cm)", colour = "Species", shape = "Species") +
  theme_bw() +
  theme(legend.position="bottom") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())

cor.test(df.cor$proplength_cm, df.cor$maxshoot_cm, method = "pearson")

#RGR per proplength
df %>%
  ggplot(aes(x = proplength_cm, y = RGR)) +
  geom_point(aes(colour = species, shape = as.factor(treatment)), alpha = 0.7) +
  scale_colour_brewer(palette = "Dark2", labels= speciesnames) +
  geom_smooth(method = "lm", formula = (y ~ log(x)), se = FALSE, colour = "black", size = 0.1) +
  theme_light() +
  labs(x = "Propagule length (cm)", y = "RGR", colour = "Species", shape = "Treatment") +
  theme_bw() +
  theme(legend.position="bottom") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) 

no_na_rgr <- df %>%filter(!is.na(RGR), !is.infinite(RGR))
cor.test(log(no_na_rgr$proplength_cm), no_na_rgr$RGR, method = "pearson") 
summary(lm(RGR ~ proplength_cm, no_na_rgr))

####################################################
####################################################
############## --- Supp. results ----- #############
####################################################
####################################################

# SURVIVAL
states <- survival %>%
  rowwise() %>%
  mutate(status = case_when(
    state == -1 ~ NA_real_, #not germinated is ignored
    state == 0 ~ 1,         #dead = dead
    state == 1 ~ 1,         #toppling = dead
    state == 2 ~ 0          #living = alive
  )) %>%
  mutate(time = day) %>% 
  filter(species %in% c("AM", "BG", "KO", "LR", "RS", "SA")) #AC (all dead) and BS (all alive) are excluded

fit1 <-  survfit(Surv(time, status) ~ treatment, data = states)
dif1 <- survdiff(Surv(time, status) ~ treatment, data = states)
dif1

states_erosion <- states %>%  filter(treatment == -6) 
fit2 <-  survfit(Surv(time, status) ~ species, data = states_erosion)
dif2 <- survdiff(Surv(time, status) ~ species, data = states_erosion)
dif2
summary(fit2)

res <- pairwise_survdiff(Surv(time, status) ~ species, data = states_erosion)
res

# GROWTH
Anova(lm(maxshoot_cm ~ species * treatment, df, contrasts=list(species=contr.sum)), type=3)
Anova(lm(maxroot_cm ~ species * treatment, df, contrasts=list(species=contr.sum)), type=3)
Anova(lm(shootgrowth_cm ~ species * treatment, df, contrasts=list(species=contr.sum)), type=3)
Anova(lm(RGR ~ species * treatment, no_na_rgr, contrasts=list(species=contr.sum)), type=3)

summary(lm(maxshoot_cm ~ species * treatment, data = df))
summary(lm(maxroot_cm ~ species * treatment, data = df))
summary(lm(shootgrowth_cm ~ species * treatment, data = df))
summary(lm(RGR ~ species * treatment, data = no_na_rgr))



# root length and water temperature
df %>%
  ggplot(aes(x = watertemp_C, y = maxroot_cm)) +
  geom_boxplot(aes(fill = species)) +
  scale_fill_brewer(palette = "Dark2", labels= speciesnames) +
  theme_classic() 

# NR OF ROOTS
df %>%
  ggplot(aes(x = species, y = nr_roots)) +
  geom_boxplot(aes(fill = as.factor(treatment))) +
  scale_fill_manual(values = treatcols) +
  theme_bw() +
  theme(legend.position="bottom") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  labs(x = "Species", y = "Number of primary roots", fill ="Cumulative bed level change (cm)")

df %>% shapiro_test(nr_roots)
df %>% kruskal_test(nr_roots ~ species)
df %>% dunn_test(nr_roots ~ species) %>% print(n = 28)

cor.test(df$nr_roots, df$CEDtopple_cm, method = "pearson")

# DEAD SEEDLINGS
deadseedlings %>%
  ggplot(aes(x = -cumtreat_cm, y = maxroot_cm)) +
  geom_jitter(aes(colour = species), size = 3 , width = 0.2, alpha = 0.7) +
  facet_wrap(~state) +
  scale_colour_brewer(palette = "Dark2", labels= speciesnames) +
  labs(x = "Cumulative erosion (cm)", 
       y = "Max. root length (cm)",
       colour = "Species") +
  theme_bw() +
  theme(legend.position="bottom") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) 

# SHOOT GROWTH OVER TIME
growth %>%
  group_by(species, treatment, potnumber) %>%
  mutate(totalgrowth_cm =  true_length_cm - first(true_length_cm)) %>%
  group_by(day, species, treatment) %>%
  mutate(meangrowth = mean(totalgrowth_cm, na.rm = TRUE),
         meanlength = mean(true_length_cm, na.rm = TRUE)) %>%
  ggplot(aes(x = day, y = totalgrowth_cm, colour = as.factor(treatment)))+
  geom_point(alpha = 0.3) +
  facet_wrap(~species, nrow = 3) +
  scale_colour_manual(values = treatcols) +
  theme_light() +
  geom_line(aes(y = meangrowth), size = 1)+
  theme(legend.position = "bottom") +
  labs(x = "Day", y = "Total shoot growth (cm)", colour = "Treatment") +
  theme_bw() +
  theme(legend.position="bottom") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+
  geom_vline(xintercept = 15, colour= "black", linetype = 2) +
  geom_vline(xintercept = 22, colour= "black", linetype = 2) +
  geom_vline(xintercept = 29, colour= "black", linetype = 2) +
  scale_x_continuous(breaks = c(7,10,13,17,20,24,27,31,34)) 

# PCA
pca <- prcomp(df.cor, center = TRUE,scale. = TRUE, )
fviz_pca_var(pca, col.var = "black", geom = c("arrow", "text")) +
  theme_classic()


# Fig. S7
df %>%
  mutate(rsratio = maxroot_cm/maxshoot_cm) %>%
  filter(!is.na(rsratio), !is.infinite(rsratio), !is.na(netCEDtopple_cm)) %>% #remove missing data & 1 outlier
  ggplot(aes(x = maxroot_cm, y = maxshoot_cm, colour = netCEDtopple_cm)) +
  geom_point(size = 3, alpha = 0.8) +
  theme_bw() +
  theme(legend.position="bottom") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  scale_colour_viridis(direction = 1, option = "D") +
  labs(x = "Max. root length (cm)", y = "Shoot length (cm)", colour = "Net CED toppling (cm)")

df %>%
  filter(!is.na(netCEDtopple_cm)) %>%
  ggplot(aes(x = root_g, y = above_g, colour = netCEDtopple_cm)) +
  geom_point(size = 3, alpha = 0.8) +
  scale_colour_manual(values = treatcols) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  scale_colour_viridis(direction = 1, option = "D") +
  labs(x = "Root dryweight (g)", y = "Abovegroud dryweight (g)", colour = "Net CED toppling (cm)")

df %>%
  filter(!is.na(species)) %>%
  ggplot(aes(x = rootshootratio_cm, y = netCEDtopple_cm)) +
  geom_point(aes(colour = species), alpha = 0.8, size = 3) +
  scale_colour_brewer(palette = "Dark2", labels = speciesnames) +
  theme_bw() +
  theme(legend.position="bottom") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  labs(x = "Root (cm)/Shoot (cm) ratio",y = "Net CEDtoppling (cm)", colour = "Species")

df %>%
  ggplot(aes(x = rsratio_g, y = netCEDtopple_cm)) +
  geom_point(aes(colour = species), alpha = 0.8, size = 3) +
  scale_colour_brewer(palette = "Dark2", labels = speciesnames) +
  theme_bw() +
  theme(legend.position="bottom") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  labs(x = "Root (g)/Shoot (g) ratio",
       y = "Net CEDtoppling (cm)",
       colour = "Species") +
  xlim(c(0,0.7)) + ylim(0,15)


# ABSOLUTE GROWTH RATE
df %>%
  group_by(species) %>%
  mutate(meanproplength =mean(proplength_cm, na.rm = TRUE),
         meanAGR = mean(AGR, na.rm = TRUE),
         varproplength = var(proplength_cm, na.rm = TRUE),
         varAGR = var(AGR, na.rm = TRUE)) %>%
  ggplot(aes(x = proplength_cm, y = AGR)) +
  geom_point(aes(colour = species, shape = as.factor(treatment)), alpha = 0.7) +
  geom_point(aes(x = meanproplength, y = meanAGR, colour = species), size = 2) +
  geom_errorbarh(aes(y = meanAGR, xmax = meanproplength + varproplength, 
                     xmin = meanproplength - varproplength, colour = species), 
                 height = 0.01, size = 0.75) +
  geom_errorbar(aes(x = meanproplength, ymin = meanAGR - varAGR, ymax = meanAGR + varAGR,
                    colour = species), width = 0.5, size = 0.75) +
  scale_colour_brewer(palette = "Dark2", labels= speciesnames) +
  theme_classic()

# ONGOING CED
onced %>%
  ggplot(aes(x = day, y = longestroot_cm, colour = type)) +
  geom_point() +
  geom_line(aes(y = meanlength)) +
  theme_classic()

onced %>%
ggplot(aes(x = day, y = shoot_cm, colour = type)) +
  geom_point() +
  geom_line(aes(y = meanshoot)) +
  theme_classic()
